# Purge Registres Décès INSEE

Ce programme s'adresse essentiellement aux greffiers des pieux, paroisse et
branches de France, de l'Église de Jésus Christ des Saints des Derniers Jours.

## Objectif

La tenue à jour des registres de l'Église n'est pas une tache aisée. Une des
difficultés est liée au fait que lorsqu'un membre s'éloigne de l'Église, ses
informations personnelles (adresse, téléphone, etc) ne sont plus mises à jour.

L'INSEE tient un fichier des personnes décédées en France de 1970 à
aujourd'hui. Ce fichier est disponible en [données
ouvertes](https://fr.wikipedia.org/wiki/Donn%C3%A9es_ouvertes) sur [le site du
gouvernement](https://www.data.gouv.fr/fr/datasets/fichier-des-personnes-decedees/).
Ce fichier est une aubaine, car il permet de savoir si un membre de l'Église
est décédé sans que nous le sachions. Si une personne figure à la fois dans
les registres de l'Église et dans le fichier de l'INSEE, alors une mise à jour
du registre de l'Église est nécessaire.

Parcourir à la main le registre de membres de paroisse est une tache longue et
fastidieuse. Ce programme permet de comparer automatiquement le registre de
paroisse avec le fichier de l'INSEE, et donne la liste des membres trouvés
dans le fichier de l'INSEE.

Le fichier de l'INSEE est actualisé de façon mensuelle. Il semble intéressant
d'utiliser ce programme régulièrement (une fois par an par exemple) pour
s'assurer que les registres restent à jour.

## Pré-requis

### Logiciels
- Git
- Python 3.6
- Virtualenv

Testé uniquement sur GNU/Linux (Ubuntu 18.4)

### Données

Le fichier de l'INSEE tel qu'il est présenté n'est pas facile à
exploiter. Je l'ai donc converti en base de donnée SQLite, plus
pratique d'utilisation. Pour le télécharger, [rendez-vous
ici](https://git.roflcopter.fr/sdjgeek/purge-registres-deces-insee/-/wikis/home#t%C3%A9l%C3%A9charger-la-base-de-donn%C3%A9e).

## Installation

- Cloner le code

```bash
git clone -b latest-release https://git.roflcopter.fr/sdjgeek/purge-registres-deces-insee.git
cd purge-registres-deces-insee
```

- Mettre en place l'environnement virtuel Python

```bash
python3 -m venv localenv
. localenv/bin/activate
pip install -r requirements.txt
```

## Utilisation

Le début du fichier ```trouver_deces.py``` contient les paramètres à configurer :

- chemin_base_donnees : Le chemin vers le fichier téléchargé (me contacter)
- numeros_unites : La liste des unités que le programme doit tester. La liste commence par le caractère '['. Les
  numéros d'unités sont séparés par des virgules. La liste se termine par le caractère ']'. Par exemple
  [47823, 67745, 31456]
- cookie : Les cookies de la session au compte SDJ. Pour obtenir ces cookies il faut
  1- Ouvrir Firefox
  2- Ouvrir les outils de développement : CTRL + MAJ + E
  3- Aller sur le site des outils pour greffiers : https://lds.org/lcr
  4- Entrer identifiant et mot de passe SDJ
  5- Aller dans la liste des membres
  6- Dans l'outil de développement, cliquer sur la dernière ligne
  7- Dans le panneau de droite, dans la section "En-tête de la requête", rechercher le champ "cookie"
  8- Copier la valeur contenue dans ce champ
- chemin_repertoire_sortie : Le chemin vers le répertoire qui contiendra la fichiers de sortie

Une fois la configuration effectuée, lancer le script :

```bash
. localenv/bin/activate
python trouver_deces.py
```

Le script mettra un peu de temps à s'exécuter. En fin d'exécution, le fichier
liste_membres_decedes_unite_{unite}.txt contiendra la liste des membres
trouvés dans le fichier de l'INSEE. Il est recommandé de contrôler les
informations du membres avant de le déclarer comme décédé dans les registres
de l'Église.

## Licence

Copyright (c) 2020 Sdj Geek

Ce logiciel est sous licence MIT/X Consortium. Elle donne à toute personne
recevant le logiciel (et ses fichiers) le droit illimité de l'utiliser, le
copier, le modifier, le fusionner, le publier, le distribuer, le vendre et le
"sous-licencier" (l'incorporer dans une autre licence). La seule obligation
est d'incorporer la notice de licence et de copyright dans toutes les
copies. Voir le fichier [LICENSE](LICENSE) pour le texte complet.